@@ -46,11 +46,11 @@ static object LI9();
 #define VMV9
 #define VMR9(VMT9) return(VMT9);
 static object LI10();
-#define VMB10 register object *base=vs_top;
-#define VMS10  register object *sup=vs_top+1;vs_top=sup;
-#define VMV10 vs_reserve(1);
-#define VMR10(VMT10) vs_top=base ; return(VMT10);
-#define VM10 1
+#define VMB10
+#define VMS10
+#define VMV10
+#define VMR10(VMT10) return(VMT10);
+#define VM10 0
 #define VM9 0
 #define VM8 0
 #define VM7 0
@@ -60,8 +60,8 @@ static object LI10();
 #define VM3 0
 #define VM2 0
 #define VM1 0
-static char * VVi[15]={
-#define Cdata VV[14]
+static char * VVi[14]={
+#define Cdata VV[13]
 (char *)(LI1),
 (char *)(LI2),
 (char *)(LI3),
@@ -74,8 +74,6 @@ static char * VVi[15]={
 (char *)(LI10)
 };
 #define VV ((object *)VVi)
-static  LnkT13() ;
-static  (*Lnk13)() = LnkT13;
 static object  LnkTLI12() ;
 static object  (*LnkLI12)() = LnkTLI12;
 static object  LnkTLI11() ;
