@@ -1,6 +1,6 @@
 /* Copyright (C) 1989, 1997, 1998, 1999 Aladdin Enterprises.  All rights reserved. */
 
-/*$Id: ansi2knr.c,v 1.1 2000/04/22 23:32:38 kevin Exp $*/
+/*$Id: ansi2knr.c,v 1.3 2002/01/31 19:17:46 camm Exp $*/
 /* Convert ANSI C function definitions to K&R ("traditional C") syntax */
 
 /*
@@ -111,7 +111,7 @@ program under the GPL.
 /* or without the GNU configure machinery. */
 
 #if HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
 #include <stdio.h>
