@@ -1,5 +1,5 @@
 #ifndef MAXPAGE
-#define MAXPAGE 32768
+#define MAXPAGE (32 * 1024)
 #endif
 #ifndef VSSIZE
 #define VSSIZE 8192
