@@ -1,5 +1,5 @@
 
-#include <cmpinclude.h>
+#include "cmpinclude.h"
 #include "arraylib.h"
 init_arraylib(){do_init(VV);}
 /*	local entry for function BEST-ARRAY-ELEMENT-TYPE	*/
@@ -30,7 +30,7 @@ T7:;
 	base[0]= (V2);
 	base[1]= VV[1];
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk17)();
+	(void) (*Lnk18)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T10;}
@@ -47,7 +47,7 @@ T18:;
 	base[1]= (V2);
 	base[2]= (V7);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk17)();
+	(void) (*Lnk18)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T22;}
@@ -76,7 +76,7 @@ T41:;
 	base[1]= (V2);
 	base[2]= (V13);
 	vs_top=(vs_base=base+1)+2;
-	(void) (*Lnk17)();
+	(void) (*Lnk18)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T45;}
@@ -138,7 +138,7 @@ static object LI2(V16,va_alist)
 	goto T57;}
 	V17= make_cons((V17),Cnil);
 T57:;
-	V18= (*(LnkLI21))((V18));
+	V18= (*(LnkLI22))((V18));
 	if(!((length((V17)))==(1))){
 	goto T64;}
 	{register object V27;
@@ -176,7 +176,7 @@ T64:;
 	{register object V32;
 	base[1]= (V18);
 	vs_top=(vs_base=base+1)+1;
-	(void) (*Lnk22)();
+	(void) (*Lnk23)();
 	vs_top=sup;
 	base[0]= vs_base[0];
 	base[1]= (V26);
@@ -185,7 +185,7 @@ T64:;
 	base[4]= (V25);
 	base[5]= (V17);
 	vs_top=(vs_base=base+0)+6;
-	(void) (*Lnk23)();
+	(void) (*Lnk24)();
 	vs_top=sup;
 	V32= vs_base[0];
 	if(((V23))==Cnil){
@@ -212,12 +212,12 @@ T98:;
 	V34= vs_base[0];
 T112:;
 	base[0]= (V32);
-	base[1]= (*(LnkLI24))((V20),(V34));
+	base[1]= (*(LnkLI25))((V20),(V34));
 	base[2]= (V34);
 	vs_top=(vs_base=base+0)+3;
-	(void) (*Lnk25)();
+	(void) (*Lnk26)();
 	vs_top=sup;
-	if(((*(LnkLI26))((V34),(V17)))==Cnil){
+	if(((*(LnkLI27))((V34),(V17)))==Cnil){
 	goto T119;}
 	goto T102;
 T119:;
@@ -239,7 +239,7 @@ TTL:;
 	VMR3(V40)}
 T125:;
 	{object V41;
-	V41= (*(LnkLI26))(cdr((V38)),cdr((V39)));
+	V41= (*(LnkLI27))(cdr((V38)),cdr((V39)));
 	if(((V41))==Cnil){
 	goto T129;}
 	if(!(((fix(car((V38))))+1)>=(fix(car((V39)))))){
@@ -289,7 +289,7 @@ static object LI5(va_alist)
 	{object V53;
 	V54 = make_fixnum(length((V51)));
 	V53= make_cons(V54,Cnil);
-	{object V55 = (VFUN_NARGS=5,(*(LnkLI27))((V53),VV[8],Ct,VV[9],(V51)));
+	{object V55 = (VFUN_NARGS=5,(*(LnkLI28))((V53),VV[8],Ct,VV[9],(V51)));
 	VMR5(V55)}}}
 	}
 /*	local entry for function ARRAY-DIMENSIONS	*/
@@ -957,7 +957,7 @@ T312:;
 	vs_top=sup;
 	V182= vs_base[0];
 	V183 = make_fixnum(V174);
-	(void)((VFUN_NARGS=6,(*(LnkLI28))((V172),/* INLINE-ARGS */V181,VV[8],V182,VV[11],V183)));
+	(void)((VFUN_NARGS=6,(*(LnkLI29))((V172),/* INLINE-ARGS */V181,VV[8],V182,VV[11],V183)));
 	(void)(aset1((V172),V174,(V171)));
 	base[0]= (V172);
 	base[1]= make_fixnum((V174)+1);
@@ -1007,7 +1007,7 @@ static object LI25(V190,V189,va_alist)
 	{register object V191;
 	register object V192;
 	register object V193;
-	register object V194;
+	object V194;
 	object V195;
 	object V196;
 	object V197;
@@ -1030,182 +1030,218 @@ static object LI25(V190,V189,va_alist)
 	V198=(Vcs[7]);
 	V199=(Vcs[8]);
 	V200=(Vcs[9]);
+	{register object V202;
+	V202= Cnil;
 	if(!(type_of((V192))==t_fixnum||type_of((V192))==t_bignum)){
-	goto T337;}
+	goto T338;}
 	V192= make_cons((V192),Cnil);
-T337:;
-	{register object x= VV[11],V202= (V193);
-	while(!endp(V202))
-	if(eql(x,V202->c.c_car)){
-	goto T344;
-	}else V202=V202->c.c_cdr;
-	goto T343;}
-T344:;
+T338:;
+	{register object x= VV[11],V203= (V193);
+	while(!endp(V203))
+	if(eql(x,V203->c.c_car)){
+	V202= V203;
+	goto T346;
+	}else V203=V203->c.c_cdr;
+	V202= Cnil;}
+T346:;
+	if(((V202))==Cnil){
+	goto T344;}
 	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk29)();
+	(void) (*Lnk30)();
 	vs_top=sup;
 	if((vs_base[0])!=Cnil){
-	goto T341;}
+	goto T342;}
 	base[0]= VV[13];
 	vs_top=(vs_base=base+0)+1;
 	Lerror();
 	vs_top=sup;
-	goto T341;
-T343:;
+	goto T342;
+T344:;
 	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk29)();
+	(void) (*Lnk30)();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
-	goto T341;}
+	goto T342;}
 	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
 	Lfill_pointer();
 	vs_top=sup;
-	V203= vs_base[0];
-	V193= ON_STACK_CONS(V203,(V193));
+	V204= vs_base[0];
+	V193= ON_STACK_CONS(V204,(V193));
 	V193= ON_STACK_CONS(VV[11],(V193));
-T341:;
+T342:;
 	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
 	Larray_element_type();
 	vs_top=sup;
 	V194= vs_base[0];
 	if(((V194))==(Ct)){
-	goto T360;}
+	goto T362;}
 	V193= ON_STACK_CONS((V194),(V193));
 	V193= ON_STACK_CONS(VV[8],(V193));
-T360:;
-	{register object x= VV[14],V204= (V193);
-	while(!endp(V204))
-	if(type_of(V204->c.c_car)==t_cons &&eql(x,V204->c.c_car->c.c_car)){
-	goto T366;
-	}else V204=V204->c.c_cdr;}
+T362:;
+	{register object x= VV[14],V205= (V193);
+	while(!endp(V205))
+	if(eql(x,V205->c.c_car)){
+	goto T368;
+	}else V205=V205->c.c_cdr;}
 	base[0]= (V191);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk30)();
+	(void) (*Lnk31)();
 	vs_top=sup;
-	V205= vs_base[0];
-	V193= ON_STACK_CONS(V205,(V193));
+	V206= vs_base[0];
+	V193= ON_STACK_CONS(V206,(V193));
 	V193= ON_STACK_CONS(VV[14],(V193));
-T366:;
-	{register object V206;
+T368:;
+	{register object V207;
 	base[0]= (V192);
 	base[1]= VV[15];
 	base[2]= Ct;
-	{object V207;
-	V207= (V193);
+	{object V208;
+	V208= (V193);
 	 vs_top=base+3;
-	 while(!endp(V207))
-	 {vs_push(car(V207));V207=cdr(V207);}
+	 while(!endp(V208))
+	 {vs_push(car(V208));V208=cdr(V208);}
 	vs_base=base+0;}
-	(void) (*Lnk27)();
+	(void) (*Lnk28)();
 	vs_top=sup;
-	V206= vs_base[0];
+	V207= vs_base[0];
 	if((cdr((V192)))==Cnil){
-	goto T380;}
-	V208= cdr((V192));
-	V209= (*(LnkLI31))((V191));
-	if(!(equal(/* INLINE-ARGS */V208,cdr(/* INLINE-ARGS */V209)))){
-	goto T381;}
+	goto T382;}
+	V209= cdr((V192));
+	V210= (*(LnkLI32))((V191));
+	if(!(equal(/* INLINE-ARGS */V209,cdr(/* INLINE-ARGS */V210)))){
+	goto T383;}
 	if(!(((V194))==(VV[16]))){
-	goto T380;}
+	goto T382;}
 	base[0]= (V192);
 	vs_top=(vs_base=base+0)+1;
 	Llast();
 	vs_top=sup;
-	V210= vs_base[0];
-	{int V211= fix(car(V210));
-	if(!((0)==((V211>=0&&(8)>0?(V211)%(8):imod(V211,8))))){
-	goto T381;}}
-T380:;
+	V211= vs_base[0];
+	{int V212= fix(car(V211));
+	if(!((0)==((V212>=0&&(8)>0?(V212)%(8):imod(V212,8))))){
+	goto T383;}}
+T382:;
 	base[0]= (V191);
-	base[1]= (V206);
+	base[1]= (V207);
 	base[2]= small_fixnum(0);
 	base[3]= small_fixnum(0);
-	base[5]= (V206);
+	base[5]= (V207);
 	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk32)();
-	vs_top=sup;
-	V212= vs_base[0];
-	base[5]= (V191);
-	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk32)();
-	vs_top=sup;
-	V213= vs_base[0];
-	base[4]= (number_compare(V212,V213)<=0?(V212):V213);
-	vs_top=(vs_base=base+0)+5;
 	(void) (*Lnk33)();
 	vs_top=sup;
-	goto T379;
-T381:;
-	{register object V214;
+	V213= vs_base[0];
+	base[5]= (V191);
+	vs_top=(vs_base=base+5)+1;
+	(void) (*Lnk33)();
+	vs_top=sup;
+	V214= vs_base[0];
+	base[4]= (number_compare(V213,V214)<=0?(V213):V214);
+	vs_top=(vs_base=base+0)+5;
+	(void) (*Lnk34)();
+	vs_top=sup;
+	goto T381;
+T383:;
+	{register object V215;
 	base[0]= make_fixnum(length((V192)));
 	base[1]= VV[7];
 	base[2]= small_fixnum(0);
 	vs_top=(vs_base=base+0)+3;
 	Lmake_list();
 	vs_top=sup;
-	V214= vs_base[0];
-T405:;
+	V215= vs_base[0];
+T407:;
 	base[0]= (V191);
-	{object V215;
-	V215= (V214);
-	 vs_top=base+1;
-	 while(!endp(V215))
-	 {vs_push(car(V215));V215=cdr(V215);}
-	vs_base=base+0;}
-	(void) (*Lnk34)();
-	vs_top=sup;
-	if((vs_base[0])==Cnil){
-	goto T408;}
-	base[0]= (V206);
-	base[2]= (V191);
 	{object V216;
-	V216= (V214);
-	 vs_top=base+3;
+	V216= (V215);
+	 vs_top=base+1;
 	 while(!endp(V216))
 	 {vs_push(car(V216));V216=cdr(V216);}
+	vs_base=base+0;}
+	(void) (*Lnk35)();
+	vs_top=sup;
+	if((vs_base[0])==Cnil){
+	goto T410;}
+	base[0]= (V207);
+	base[2]= (V191);
+	{object V217;
+	V217= (V215);
+	 vs_top=base+3;
+	 while(!endp(V217))
+	 {vs_push(car(V217));V217=cdr(V217);}
 	vs_base=base+2;}
 	Laref();
 	vs_top=sup;
 	base[1]= vs_base[0];
-	base[2]= (V214);
+	base[2]= (V215);
 	vs_top=(vs_base=base+0)+3;
-	(void) (*Lnk25)();
+	(void) (*Lnk26)();
 	vs_top=sup;
-T408:;
-	if(((*(LnkLI26))((V214),(V192)))==Cnil){
-	goto T418;}
-	goto T379;
-T418:;
-	goto T405;}
-T379:;
+T410:;
+	if(((*(LnkLI27))((V215),(V192)))==Cnil){
+	goto T420;}
+	goto T381;
+T420:;
+	goto T407;}
+T381:;
 	base[0]= (V191);
-	base[1]= (V206);
+	base[1]= (V207);
 	vs_top=(vs_base=base+0)+2;
 	siLreplace_array();
 	vs_top=sup;
-	{object V217 = vs_base[0];
-	VMR25(V217)}}}
+	V202= cadr((V202));
+	if(((V202))==Cnil){
+	goto T430;}
+	if(!(eql(Ct,(V202)))){
+	goto T434;}
+	base[0]= (V191);
+	base[2]= (V191);
+	vs_top=(vs_base=base+2)+1;
+	(void) (*Lnk33)();
+	vs_top=sup;
+	base[1]= vs_base[0];
+	vs_top=(vs_base=base+0)+2;
+	siLfill_pointer_set();
+	vs_top=sup;
+	goto T430;
+T434:;
+	if(!(type_of((V202))==t_fixnum)){
+	goto T440;}
+	base[0]= (V191);
+	base[1]= (V202);
+	vs_top=(vs_base=base+0)+2;
+	siLfill_pointer_set();
+	vs_top=sup;
+	goto T430;
+T440:;
+	base[0]= VV[17];
+	base[1]= (V202);
+	vs_top=(vs_base=base+0)+2;
+	Lerror();
+	vs_top=sup;
+T430:;
+	{object V218 = (V191);
+	VMR25(V218)}}}}
 	}}
-static LnkT34(){ call_or_link(VV[34],&Lnk34);} /* ARRAY-IN-BOUNDS-P */
-static LnkT33(){ call_or_link(VV[33],&Lnk33);} /* COPY-ARRAY-PORTION */
-static LnkT32(){ call_or_link(VV[32],&Lnk32);} /* ARRAY-TOTAL-SIZE */
-static object  LnkTLI31(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[31],&LnkLI31,1,ap);} /* ARRAY-DIMENSIONS */
-static LnkT27(){ call_or_link(VV[27],&Lnk27);} /* MAKE-ARRAY */
-static LnkT30(){ call_or_link(VV[30],&Lnk30);} /* STATICP */
-static LnkT29(){ call_or_link(VV[29],&Lnk29);} /* ARRAY-HAS-FILL-POINTER-P */
-static object  LnkTLI28(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[28],&LnkLI28,ap);} /* ADJUST-ARRAY */
-static object  LnkTLI27(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[27],&LnkLI27,ap);} /* MAKE-ARRAY */
-static object  LnkTLI26(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[26],&LnkLI26,2,ap);} /* INCREMENT-CURSOR */
-static LnkT25(){ call_or_link(VV[25],&Lnk25);} /* ASET-BY-CURSOR */
-static object  LnkTLI24(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[24],&LnkLI24,2,ap);} /* SEQUENCE-CURSOR */
-static LnkT23(){ call_or_link(VV[23],&Lnk23);} /* MAKE-ARRAY1 */
-static LnkT22(){ call_or_link(VV[22],&Lnk22);} /* GET-AELTTYPE */
-static object  LnkTLI21(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[21],&LnkLI21,1,ap);} /* BEST-ARRAY-ELEMENT-TYPE */
-static LnkT17(){ call_or_link(VV[17],&Lnk17);} /* SUBTYPEP */
+static LnkT35(){ call_or_link(VV[35],&Lnk35);} /* ARRAY-IN-BOUNDS-P */
+static LnkT34(){ call_or_link(VV[34],&Lnk34);} /* COPY-ARRAY-PORTION */
+static LnkT33(){ call_or_link(VV[33],&Lnk33);} /* ARRAY-TOTAL-SIZE */
+static object  LnkTLI32(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[32],&LnkLI32,1,ap);} /* ARRAY-DIMENSIONS */
+static LnkT28(){ call_or_link(VV[28],&Lnk28);} /* MAKE-ARRAY */
+static LnkT31(){ call_or_link(VV[31],&Lnk31);} /* STATICP */
+static LnkT30(){ call_or_link(VV[30],&Lnk30);} /* ARRAY-HAS-FILL-POINTER-P */
+static object  LnkTLI29(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[29],&LnkLI29,ap);} /* ADJUST-ARRAY */
+static object  LnkTLI28(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[28],&LnkLI28,ap);} /* MAKE-ARRAY */
+static object  LnkTLI27(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[27],&LnkLI27,2,ap);} /* INCREMENT-CURSOR */
+static LnkT26(){ call_or_link(VV[26],&Lnk26);} /* ASET-BY-CURSOR */
+static object  LnkTLI25(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[25],&LnkLI25,2,ap);} /* SEQUENCE-CURSOR */
+static LnkT24(){ call_or_link(VV[24],&Lnk24);} /* MAKE-ARRAY1 */
+static LnkT23(){ call_or_link(VV[23],&Lnk23);} /* GET-AELTTYPE */
+static object  LnkTLI22(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_proc(VV[22],&LnkLI22,1,ap);} /* BEST-ARRAY-ELEMENT-TYPE */
+static LnkT18(){ call_or_link(VV[18],&Lnk18);} /* SUBTYPEP */
 
 #ifdef SYSTEM_SPECIAL_INIT
 SYSTEM_SPECIAL_INIT
