@@ -74,7 +74,7 @@ static object LI15();
 #define VC18
 #define VC19
 #define VC20 object  V149 ,V148 ,V145 ,V144;
-#define VC21 object  V182 ,V181 ,V180; GEN  V179= 0,V179alloc ,V178= 0,V178alloc; object  V166 ,V165 ,V164; GEN  V163= 0,V163alloc ,V162= 0,V162alloc;
+#define VC21 object  V182 ,V181 ,V180 ,V179 ,V178 ,V166 ,V165 ,V164 ,V163 ,V162;
 static L21();
 #define VC22 object  V186 ,V185;
 static L20();
