@@ -1,5 +1,5 @@
 
-#include <cmpinclude.h>
+#include "cmpinclude.h"
 #include "evalmacros.h"
 init_evalmacros(){do_init(VV);}
 /*	macro definition for DEFVAR	*/
@@ -272,7 +272,7 @@ static L9()
 	base[5]= base[4];
 	base[6]= Cnil;
 	vs_top=(vs_base=base+5)+2;
-	(void) (*Lnk43)();
+	(void) (*Lnk46)();
 	if(vs_base>=vs_top){vs_top=sup;goto T56;}
 	V37= vs_base[0];
 	vs_base++;
@@ -965,4 +965,51 @@ static L26()
 	vs_top=(vs_base=base+7)+1;
 	return;
 }
-static LnkT43(){ call_or_link(VV[43],&Lnk43);} /* FIND-DOC */
+/*	macro definition for DECLAIM	*/
+
+static L27()
+{register object *base=vs_base;
+	register object *sup=base+VM27; VC27
+	vs_reserve(VM27);
+	check_arg(2);
+	vs_top=sup;
+	{object V146=base[0]->c.c_cdr;
+	base[2]= V146;}
+	{object V148;
+	object V149= base[2];
+	if(endp(V149)){
+	V147= Cnil;
+	goto T312;}
+	base[3]=V148=MMcons(Cnil,Cnil);
+T313:;
+	(V148->c.c_car)= list(2,VV[45],list(2,VV[2],(V149->c.c_car)));
+	if(endp(V149=MMcdr(V149))){
+	V147= base[3];
+	goto T312;}
+	V148=MMcdr(V148)=MMcons(Cnil,Cnil);
+	goto T313;}
+T312:;
+	base[3]= listA(3,VV[43],VV[44],V147);
+	vs_top=(vs_base=base+3)+1;
+	return;
+}
+/*	macro definition for LAMBDA	*/
+
+static L28()
+{register object *base=vs_base;
+	register object *sup=base+VM28; VC28
+	vs_reserve(VM28);
+	check_arg(2);
+	vs_top=sup;
+	{object V151=base[0]->c.c_cdr;
+	base[2]= V151;}
+	base[3]= list(2,VV[22],make_cons(VV[23],base[2]));
+	vs_top=(vs_base=base+3)+1;
+	return;
+}
+static LnkT46(){ call_or_link(VV[46],&Lnk46);} /* FIND-DOC */
+
+#ifdef SYSTEM_SPECIAL_INIT
+SYSTEM_SPECIAL_INIT
+#endif
+
