@@ -1149,7 +1149,7 @@ int size;
 	  }
 
 	  }
-#endif BABY_MALLOC_SIZE	
+#endif /*  BABY_MALLOC_SIZE	 */
 
 	
 	if(ptr == NULL) return malloc(size);
@@ -1199,7 +1199,7 @@ char *ptr;
 #endif
 
 
-#ifndef GNUMALLOC
+#ifndef GNU_MALLOC
 char *
 memalign(align,size)
      int align,size;
