@@ -24,6 +24,8 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 	IMPLEMENTATION-DEPENDENT
 */
 
+#include <string.h>
+
 #define IN_MAIN
 
 #ifdef KCLOVM
@@ -58,7 +60,7 @@ bool saving_system ;
 #define LISP_IMPLEMENTATION_VERSION "April 1994"
 
 char *system_directory;
-char system_directory_buf[MAXPATHLEN];
+
 int page_multiple=1;
 
 
@@ -81,7 +83,6 @@ object sSAmultiply_stacksA;
 int stack_multiple=1;
 static object stack_space;
 
-char *merge_system_directory();
 
 int cssize;
 
@@ -96,14 +97,14 @@ void install_segmentation_catcher();
         struct sigstack estack;
 #endif
 #endif
- 
+
 main(argc, argv, envp) 
 int argc;
 char **argv, **envp;
 {
 	FILE *i;
 #ifdef BSD
-#ifndef SGI
+#ifdef RLIMIT_STACK
 	struct rlimit rl;
 #endif
 #endif
@@ -115,9 +116,14 @@ char **argv, **envp;
 	  /* make sure the stack is 8 byte aligned */
 	double estack_buf[SIG_STACK_SIZE];
 #endif
-	setbuf(stdin, stdin_buf);
-	setbuf(stdout, stdout_buf);
 
+#ifdef RECREATE_HEAP
+	RECREATE_HEAP
+#endif
+	
+	setbuf(stdin, stdin_buf); 
+	setbuf(stdout, stdout_buf);
+	
 	ARGC = argc;
 	ARGV = argv;
 #ifdef UNIX
@@ -130,8 +136,16 @@ char **argv, **envp;
 		error("can't get the program name");
 */
 	kcl_self = argv[0];
-	system_directory = system_directory_buf;
+#ifdef FIX_FILENAME
+	{ int n = strlen(kcl_self);
+	 FIX_FILENAME(Cnil,kcl_self);
+	 if (strlen(kcl_self)> n) error("name grew");
+	}
+#endif	
 	if (!initflag) {
+
+		system_directory= (char *) malloc(strlen(argv[0])+3);
+					
 		strcpy(system_directory, argv[0]);
 		if (system_directory[0] != '/')
 			strcpy(system_directory, "./");
@@ -144,6 +158,7 @@ char **argv, **envp;
 			system_directory[j] = '\0';
 		}
 	}
+
 #endif
 #ifdef AOSVS
 
@@ -201,8 +216,14 @@ char **argv, **envp;
 	install_segmentation_catcher();
 
 #ifdef BSD
+#ifndef MAX_STACK_SIZE
+#define MAX_STACK_SIZE (1<<23) /* 8Mb */
+#endif
 #ifdef RLIMIT_STACK
 	getrlimit(RLIMIT_STACK, &rl);
+        if (rl.rlim_cur == RLIM_INFINITY ||
+	    rl.rlim_cur > MAX_STACK_SIZE)
+	  rl.rlim_cur=MAX_STACK_SIZE;
 	cssize = rl.rlim_cur/4 - 4*CSGETA;
 #endif	
 #endif
@@ -230,6 +251,9 @@ char **argv, **envp;
 	if (initflag) {
 		if (saving_system) {
 			saving_system = FALSE;
+			terminal_io->sm.sm_object0->sm.sm_fp = stdin;
+			terminal_io->sm.sm_object1->sm.sm_fp = stdout;
+			init_big1();
 #ifdef INIT_CORE_END
 			INIT_CORE_END
 #endif			  
@@ -386,7 +410,6 @@ initlisp()
 	
 	NewInit();
 	init_typespec();
-	init_pari();
 	init_number();
 	init_character();
 
@@ -463,17 +486,6 @@ initlisp()
 
 }
 
-
-char *
-merge_system_directory(s)
-{
-	static char buff[MAXPATHLEN];
-	extern char *strcat();
-
-	strcpy(buff, system_directory);
-	return(strcat(buff, s));
-}
-
 vs_overflow()
 {
 	if (vs_limit > vs_org + stack_multiple *  VSSIZE)
@@ -604,7 +616,12 @@ siLgetenv()
 		name[i] = vs_base[0]->st.st_self[i];
 	name[i] = '\0';
 	if ((value = getenv(name)) != NULL)
-		vs_base[0] = make_simple_string(value);
+		{vs_base[0] = make_simple_string(value);
+#ifdef FREE_GETENV_RESULT
+		free(value);
+		
+#endif		
+		}
 	else
 		vs_base[0] = Cnil;
 }
@@ -661,9 +678,10 @@ int arg;
 #ifdef AV
 	if (&arg > cs_org - cssize + 16)
 		cs_limit = cs_org - cssize;
-#endif
+
 	else
 		error("can't reset cs_limit");
+#endif
 	vs_base[0] = Cnil;
 }
 
@@ -839,10 +857,18 @@ init_main()
 	   features=    make_cons(make_ordinary("COMMON"),
 		     make_cons(make_ordinary("KCL"), Cnil));
 	 ADD_FEATURE("AKCL");
-	 ADD_FEATURE("GCL");	 
+	 ADD_FEATURE("GCL");
+#ifdef BROKEN_O4_OPT
+	 ADD_FEATURE("BROKEN_O4_OPT");
+#endif
+#ifdef GMP
+	 ADD_FEATURE("GMP");
+#endif	 
 
 #ifdef UNIX
+#ifndef WINDOWSNT	 
 	ADD_FEATURE("UNIX");
+#endif	
 #endif
 #ifdef IEEEFLOAT
        ADD_FEATURE("IEEE-FLOATING-POINT");
@@ -857,6 +883,9 @@ init_main()
 	ADD_FEATURE("BSD");
 #endif
 
+#ifdef LITTLE_END	 
+	 ADD_FEATURE("CLX-LITTLE-ENDIAN");
+#endif
 
 #ifndef PECULIAR_MACHINE
 #define BIGM    (int)((((unsigned int)(-1))/2))	 
