@@ -7,6 +7,7 @@ to recently, for more efficient garbage collection.
 
 */
 
+
 #ifdef BSD
 /* ulong may have been defined in mp.h but the define is no longer needed */
 #undef ulong
@@ -36,6 +37,7 @@ do {register object xtmp = u;  \
 #ifdef SDEBUG
   object sdebug;
 joe1(){;}
+joe() {;}     
 #endif
 
 sgc_mark_cons(x)
@@ -105,13 +107,20 @@ BEGIN:
 		return;
 	IF_WRITABLE(x,goto OK);
 	joe();
-
+#endif 
       OK:
 	if (x->d.m)
 		return;
-
+#ifdef SDEBUG
 	if(x==sdebug) joe1();
 #endif
+	if (DBEGIN) {
+	  if (NULL_OR_ON_C_STACK(x))
+	    return;
+	} /* otherwise if DBEGIN==0 the IF_WRITABLE test will
+	     always fail on x that satisfy (NULL_OR_ON_C_STACK(x))
+	     */
+	
 	x->d.m = TRUE;
 	switch (type_of(x)) {
 	case t_fixnum:
@@ -142,11 +151,6 @@ BEGIN:
 			     sgc_mark_cons(x->s.s_plist);});
 		sgc_mark_object(x->s.s_gfdef);
 		sgc_mark_object(x->s.s_dbind);
-/*		do {int xxx= (((int)(char *)(x->s.s_dbind)-0)>>12);
-		    if((xxx & (-16384) ==0)
-		       && (sgc_type_map[xxx] & (4 | 1)))
-		      {if((x->s.s_dbind)->d.m==0)
-			 sgc_mark_object1(x->s.s_dbind);}} while(0); */
 		if (x->s.s_self == NULL)
 			break;
 		/* to do */
@@ -276,8 +280,11 @@ BEGIN:
 					mark_contblock(cp, j);
 			}
 			else if (!SGC_RELBLOCK_P(cp)) ;
-			else if (x->a.a_displaced == Cnil)
-				x->a.a_self = (object *)copy_relblock(cp, j);
+			else if (x->a.a_displaced == Cnil){
+#ifdef HAVE_ALLOCA
+			  if (cp <= core_end)  /* only if body of array not on C stack */
+#endif			  
+				x->a.a_self = (object *)copy_relblock(cp, j);}
 			else if (x->a.a_displaced->c.c_car == Cnil) {
 				i = (int)(object *)copy_relblock(cp, j)
 				  - (int)(x->a.a_self);
@@ -295,6 +302,14 @@ BEGIN:
 			goto CASE_SPECIAL;
 
         case t_bignum:
+#ifdef SDEBUG
+		if (type_map[page(x->big.big_self)] < t_contiguous)
+		  {
+		    printf("bad body for %x (%x)\n",x,cp);
+		    
+		  }
+#endif
+#ifndef GMP
 		if ((int)what_to_collect >= (int)t_contiguous) {
 		j = x->big.big_length;
 		cp = (char *)x->big.big_self;
@@ -309,12 +324,37 @@ BEGIN:
 		  
 		  printf("bad length 0x%x ",x);
 		j = j * sizeof(int);
-				cp = (char *)MP(x);
+
 		if (inheap(cp)) {
 		  if (what_to_collect == t_contiguous)
 		    mark_contblock(cp, j);
-		} else 
-		  x->big.big_self = (long *)copy_relblock(cp, j);}
+		} else {
+		  if (SGC_RELBLOCK_P(cp))
+		    x->big.big_self = (plong *)copy_relblock(cp, j);}}
+#endif /* no gmp */
+#ifndef GMP_USE_MALLOC
+		if ((int)what_to_collect >= (int)t_contiguous) {
+		  j = MP_ALLOCATED(x);
+		  cp = (char *)MP_SELF(x);
+		  if (cp == 0)
+		    break;
+#ifdef PARI
+		  if (j != lg(MP(x))  &&
+		      /* we don't bother to zero this register,
+			 and its contents may get over written */
+		      ! (x == big_register_1 &&
+			 (int)(cp) <= top &&
+			 (int) cp >= bot))
+		    printf("bad length 0x%x ",x);
+#endif
+		  j = j * MP_LIMB_SIZE;
+		  if (inheap(cp)) {
+		    if (what_to_collect == t_contiguous)
+		      mark_contblock(cp, j);
+		  } else{
+		    if (SGC_RELBLOCK_P(cp))
+		       MP_SELF(x) = (void *) copy_relblock(cp, j);}}
+#endif /* not GMP_USE_MALLOC */
 		break;
 		
 
@@ -352,7 +392,7 @@ BEGIN:
 
 #define W_SIZE (8*sizeof(int))
 		j= sizeof(int) *
-		   ((x->bv.bv_offset + x->bv.bv_dim + W_SIZE -1)/W_SIZE);
+		   ((BV_OFFSET(x) + x->bv.bv_dim + W_SIZE -1)/W_SIZE);
 		cp = x->bv.bv_self;
 		if (cp == NULL)
 			break;
@@ -388,6 +428,7 @@ BEGIN:
 		case smm_input:
 		case smm_output:
 		case smm_io:
+		case smm_socket:  
 		case smm_probe:
 			sgc_mark_object(x->sm.sm_object0);
 			sgc_mark_object(x->sm.sm_object1);
@@ -467,11 +508,19 @@ BEGIN:
 		sgc_mark_object(x->pn.pn_version);
 		break;
 
+      case t_closure:
+       { int i ;
+         if (what_to_collect == t_contiguous)
+              mark_contblock(x->cc.cc_turbo,x->cc.cc_envdim);
+         for (i= 0 ; i < x->cc.cc_envdim ; i++) {
+	   sgc_mark_object(x->cc.cc_turbo[i]);}}
+
+
 	case t_cfun:
         case t_sfun:
         case t_vfun:
+        case t_afun:
 	case t_gfun:
-        case t_afun:		
 		sgc_mark_object(x->cf.cf_name);
 		sgc_mark_object(x->cf.cf_data);
 		break;
@@ -533,7 +582,7 @@ int *bottom,*top;
     than 4 we need to mark twice
    */
 
- if (offset) {sgc_mark_stack_carefully(bottom,(((char *) top) +offset),0);}
+ if (offset) {sgc_mark_stack_carefully((((char *) top) +offset),bottom,0);}
  for (j=top ; j >= bottom ; j--)
    {if (VALID_DATA_ADDRESS_P(*j)
 	&& type_map[(p=page(*j))]< (char)t_end)
@@ -601,7 +650,7 @@ sgc_mark_phase()
 
 	sgc_mark_stack_carefully(vs_top-1,vs_org,0);
 	clear_stack(vs_top,vs_limit);
-	sgc_mark_stack_carefully(MVloc,MVloc+(sizeof(MVloc)/sizeof(object)),0);
+	sgc_mark_stack_carefully(MVloc+(sizeof(MVloc)/sizeof(object)),MVloc,0);
 	/* 
 	for (p = vs_org;  p < vs_top;  p++) {
 	  if (p && (inheap(*p)))
@@ -639,11 +688,12 @@ sgc_mark_phase()
 	  sgc_mark_all_stacks();
 #endif
 
-
+#ifdef DEBUG
 	if (debug) {
 		printf("symbol navigation\n");
 		fflush(stdout);
 	}
+#endif	
 	{int size;
 	 
 	 for (pp = pack_pointer;  pp != NULL;  pp = pp->p_link) {
@@ -747,7 +797,13 @@ sgc_sweep_phase()
 			     x->a.a_displaced->c.c_cdr = Cnil;}
 			}
 #endif OLD_DISPLACE
-			((struct freelist *)x)->f_link = f;
+#ifdef GMP_USE_MALLOC			
+			if (x->d.t == t_bignum) {
+			  mpz_clear(MP(x));
+			}
+#endif
+
+			SET_LINK(x,f);
 			x->d.m = FREE;
 			x->d.s = (int)SGC_RECENT;
 			f = x;
@@ -801,19 +857,19 @@ sgc_contblock_sweep_phase()
 		e = pagetochar(j);
 		for (p = s;  p < e;) {
 			if (get_mark_bit((int *)p)) {
-				p += 4;
+				p += PTR_ALIGN;
 				continue;
 			}
-			q = p + 4;
+			q = p + PTR_ALIGN;
 			while (q < e) {
 				if (!get_mark_bit((int *)q)) {
-					q += 4;
+					q += PTR_ALIGN;
 					continue;
 				}
 				break;
 			}
 			insert_contblock(p, q - p);
-			p = q + 4;
+			p = q + PTR_ALIGN;
 		}
 		i = j + 1;
 	}
@@ -844,7 +900,7 @@ sgc_count(yy)
  object y=yy;
  while(y)
    {count++;
-    y=F_LINK(y);}
+    y=OBJ_LINK(y);}
  printf("[length %x = %d]",yy,count);
  fflush(stdout);
 }
@@ -914,7 +970,7 @@ AGAIN:
 #ifdef DEBUG
 	  count++;
 #endif	  
-	  f= F_LINK(f);
+	  f= OBJ_LINK(f);
 	}
 #ifdef DEBUG       
        if (count!=tm->tm_nfree)
@@ -956,6 +1012,8 @@ AGAIN:
   {old_rb_start=rb_start;
    if(!saving_system)
    { new=alloc_relblock(want*PAGESIZE);
+     /* the above may cause a gc, shifting the relblock */
+     old_rb_start=rb_start;
     new= PAGE_ROUND_UP(new);
     rb_start=rb_pointer=new;
   }}}
@@ -972,19 +1030,19 @@ AGAIN:
        x=y=0;
 
 	  while (f!=0)
-	    {next=F_LINK(f);
+	    {next=OBJ_LINK(f);
 #ifdef SDEBUG	     
 	     if (f->d.m!=FREE)
 	       printf("Not FREE in freelist f=%d",f);
 #endif
 	     if (ON_SGC_PAGE(f))
-	       { F_LINK(f) =x;
+	       { SET_LINK(f,x);
 		 f->d.s = SGC_RECENT;
 		 x=f;
 		 count++;
 	       }
 	     else
-	       {F_LINK(f)=y;
+	       {SET_LINK(f,y);
 		f->d.s = SGC_NORMAL;
 		y=f;}
 	     f=next;
@@ -1028,7 +1086,7 @@ sgc_quit()
 #ifdef SDEBUG
 	    int count=0;
 	    f=tm->tm_free;
-	    while(y= F_LINK(f))
+	    while(y= (object) F_LINK(f))
 	      {if(y->d.s != SGC_RECENT)
 		printf("[bad %d]",y);
 	       count++; f=y;}
@@ -1043,9 +1101,9 @@ sgc_quit()
 	    
 #endif
 	    f=tm->tm_free;
-	    while(y= F_LINK(f))
+	    while(y= (object) F_LINK(f))
 	     f=y;
-	   F_LINK(f)=tm->tm_alt_free;
+	   F_LINK(f)= (long)(tm->tm_alt_free);
 	   }
 	/* tm->tm_free has all of the free objects */
 	tm->tm_nfree += tm->tm_alt_nfree;
@@ -1084,7 +1142,8 @@ make_writable(beg,i)
 
 int debug_fault =0;
 int fault_count =0;
-extern char *etext;
+extern char etext;
+void memprotect_handler();
 void
 memprotect_handler(sig, code, scp, addr)
           int sig, code;
@@ -1092,34 +1151,38 @@ memprotect_handler(sig, code, scp, addr)
           char *addr;     
 {int p;
  int j=page_multiple;
+ char *faddr;  /* Needed because we must not modify signal handler
+		  arguments on the stack! */
 #ifdef GET_FAULT_ADDR
- addr=GET_FAULT_ADDR(sig,code,scp,addr);
- debug_fault = (int) addr;
+  faddr=GET_FAULT_ADDR(sig,code,scp,addr); 
+ debug_fault = (int) faddr;
 #ifdef DEBUG_MPROTECT
- printf("fault:0x%x [%d] (%d)",addr,page(addr),addr >= core_end);
+ printf("fault:0x%x [%d] (%d)  ",faddr,page(faddr),faddr >= core_end);
 #endif 
- if (addr >= core_end || (unsigned int)addr < DBEGIN)
-   {if (fault_count > 300) error("fault count to high");
+ if (faddr >= core_end || (unsigned int)faddr < DBEGIN)
+   {if (fault_count > 300) error("fault count too high");
       fault_count ++;
         INSTALL_MPROTECT_HANDLER;
     return;}
-   
+#else
+ faddr = addr;
 #endif 
- p = page(addr);
+ p = page(faddr);
  p = ROUND_DOWN_PAGE_NO(p);
  if (p >= first_protectable_page
-     && addr < core_end
+     && faddr < core_end
      && !(WRITABLE_PAGE_P(p)))
    {/*   CHECK_RANGE(p,1); */
 #ifdef DEBUG_MPROTECT
-     printf("mprotect(0x%x,%x,0x%x)\n",pagetochar(p),page_multiple * PAGESIZE, sbrk(0));
+     printf("mprotect(0x%x,0x%x,0x%x)\n",
+	    pagetochar(p),page_multiple * PAGESIZE, sbrk(0));
      fflush(stdout);
 #endif     
      mprotect(pagetochar(p),page_multiple * PAGESIZE, PROT_READ_WRITE);
     while (--j >= 0)
-      sgc_type_map[p+j]=      sgc_type_map[p+j] | SGC_TEMP_WRITABLE;
+      sgc_type_map[p+j] = sgc_type_map[p+j] | SGC_TEMP_WRITABLE;
 
-#ifndef  BSD
+#ifndef BSD
  INSTALL_MPROTECT_HANDLER;
 #endif
 
@@ -1140,11 +1203,13 @@ sgc_mprotect(pbeg,n,writable)
 #ifdef DEBUG_MPROTECT
   printf("prot[%d,%d,(%d),%s]\n",pbeg,pbeg+n,writable & SGC_WRITABLE,
 	 (writable  & SGC_WRITABLE ? "writable" : "not writable"));
+  printf("mprotect(0x%x,0x%x), sbrk(0)=0x%x\n",
+	 pagetochar(pbeg), n * PAGESIZE, sbrk(0));
   fflush(stdout);
 #endif  
   if(mprotect(pagetochar(pbeg),n*PAGESIZE,
 	     (writable & SGC_WRITABLE ? PROT_READ_WRITE : PROT_READ)))
-   FEerror("Couldn't protect");}
+   FEerror("Couldn't protect",0);}
 
 
 /* for page numbers from beg below end,
@@ -1253,7 +1318,7 @@ perm_writable(p,n)
 
 
 system_error()
-{FEerror("System error");}
+{FEerror("System error",0);}
 
 
 
